@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
-from ..Qt import QtGui, QtCore, QT_LIB
+from ..Qt import QtGui, QtCore
 from ..python2_3 import asUnicode
 import numpy as np
 from ..Point import Point
 from .. import debug as debug
+from math import ceil, floor, log, log10, isfinite
 import sys
 import weakref
 from .. import functions as fn
@@ -110,9 +111,10 @@ class AxisItem(GraphicsWidget):
 
         self._linkedView = None
         if linkView is not None:
-            self.linkToView(linkView)
+            self._linkToView_internal(linkView)
 
         self.grid = False
+        
         #self.setCacheMode(self.DeviceCoordinateCache)
 
     def setStyle(self, **kwds):
@@ -511,7 +513,7 @@ class AxisItem(GraphicsWidget):
     def setRange(self, mn, mx):
         """Set the range of values displayed by the axis.
         Usually this is handled automatically by linking the axis to a ViewBox with :func:`linkToView <pyqtgraph.AxisItem.linkToView>`"""
-        if any(np.isinf((mn, mx))) or any(np.isnan((mn, mx))):
+        if not isfinite(mn) or not isfinite(mx):
             raise Exception("Not setting range to [%s, %s]" % (str(mn), str(mx)))
         self.range = [mn, mx]
         if self.autoSIPrefix:
@@ -528,8 +530,9 @@ class AxisItem(GraphicsWidget):
         else:
             return self._linkedView()
 
-    def linkToView(self, view):
-        """Link this axis to a ViewBox, causing its displayed range to match the visible range of the view."""
+    def _linkToView_internal(self, view):
+        # We need this code to be available without override,
+        # even though DateAxisItem overrides the user-side linkToView method
         self.unlinkFromView()
 
         self._linkedView = weakref.ref(view)
@@ -537,8 +540,11 @@ class AxisItem(GraphicsWidget):
             view.sigYRangeChanged.connect(self.linkedViewChanged)
         else:
             view.sigXRangeChanged.connect(self.linkedViewChanged)
-        
         view.sigResized.connect(self.linkedViewChanged)
+
+    def linkToView(self, view):
+        """Link this axis to a ViewBox, causing its displayed range to match the visible range of the view."""
+        self._linkToView_internal(view)
         
     def unlinkFromView(self):
         """Unlink this axis from a ViewBox."""
@@ -605,8 +611,8 @@ class AxisItem(GraphicsWidget):
             finally:
                 painter.end()
             self.picture = picture
-        #p.setRenderHint(p.Antialiasing, False)   ## Sometimes we get a segfault here ???
-        #p.setRenderHint(p.TextAntialiasing, True)
+        #p.setRenderHint(p.RenderHint.Antialiasing, False)   ## Sometimes we get a segfault here ???
+        #p.setRenderHint(p.RenderHint.TextAntialiasing, True)
         self.picture.play(p)
 
     def setTicks(self, ticks):
@@ -680,13 +686,13 @@ class AxisItem(GraphicsWidget):
             return []
 
         ## decide optimal minor tick spacing in pixels (this is just aesthetics)
-        optimalTickCount = max(2., np.log(size))
+        optimalTickCount = max(2., log(size))
 
         ## optimal minor tick spacing
         optimalSpacing = dif / optimalTickCount
 
         ## the largest power-of-10 spacing which is smaller than optimal
-        p10unit = 10 ** np.floor(np.log10(optimalSpacing))
+        p10unit = 10 ** floor(log10(optimalSpacing))
 
         ## Determine major/minor tick spacings which flank the optimal spacing.
         intervals = np.array([1., 2., 10., 20., 100.]) * p10unit
@@ -758,7 +764,7 @@ class AxisItem(GraphicsWidget):
             spacing, offset = tickLevels[i]
 
             ## determine starting tick
-            start = (np.ceil((minVal-offset) / spacing) * spacing) + offset
+            start = (ceil((minVal-offset) / spacing) * spacing) + offset
 
             ## determine number of ticks
             num = int((maxVal-start) / spacing) + 1
@@ -766,7 +772,7 @@ class AxisItem(GraphicsWidget):
             ## remove any ticks that were present in higher levels
             ## we assume here that if the difference between a tick value and a previously seen tick value
             ## is less than spacing/100, then they are 'equal' and we can ignore the new tick.
-            values = list(filter(lambda x: all(np.abs(allValues-x) > spacing/self.scale*0.01), values))
+            values = list(filter(lambda x: np.all(np.abs(allValues-x) > spacing/self.scale*0.01), values))
             allValues = np.concatenate([allValues, values])
             ticks.append((spacing/self.scale, values))
 
@@ -795,8 +801,8 @@ class AxisItem(GraphicsWidget):
                 ticks.append((spacing, t))
 
         if len(ticks) < 3:
-            v1 = int(np.floor(minVal))
-            v2 = int(np.ceil(maxVal))
+            v1 = int(floor(minVal))
+            v2 = int(ceil(maxVal))
             #major = list(range(v1+1, v2))
 
             minor = []
@@ -822,7 +828,7 @@ class AxisItem(GraphicsWidget):
         if self.logMode:
             return self.logTickStrings(values, scale, spacing)
 
-        places = max(0, np.ceil(-np.log10(spacing*scale)))
+        places = max(0, ceil(-log10(spacing*scale)))
         strings = []
         for v in values:
             vs = v * scale
@@ -969,7 +975,7 @@ class AxisItem(GraphicsWidget):
             if lineAlpha is None:
                 lineAlpha = 255 / (i+1)
                 if self.grid is not False:
-                    lineAlpha *= self.grid/255. * np.clip((0.05  * lengthInPixels / (len(ticks)+1)), 0., 1.)
+                    lineAlpha *= self.grid/255. * fn.clip_scalar((0.05  * lengthInPixels / (len(ticks)+1)), 0., 1.)
             elif isinstance(lineAlpha, float):
                 lineAlpha *= 255
                 lineAlpha = max(0, int(round(lineAlpha)))
@@ -1060,7 +1066,7 @@ class AxisItem(GraphicsWidget):
                 if s is None:
                     rects.append(None)
                 else:
-                    br = p.boundingRect(QtCore.QRectF(0, 0, 100, 100), QtCore.Qt.AlignCenter, asUnicode(s))
+                    br = p.boundingRect(QtCore.QRectF(0, 0, 100, 100), QtCore.Qt.AlignmentFlag.AlignCenter, asUnicode(s))
                     ## boundingRect is usually just a bit too large
                     ## (but this probably depends on per-font metrics?)
                     br.setHeight(br.height() * 0.8)
@@ -1104,7 +1110,7 @@ class AxisItem(GraphicsWidget):
                     continue
                 vstr = asUnicode(vstr)
                 x = tickPositions[i][j]
-                #textRect = p.boundingRect(QtCore.QRectF(0, 0, 100, 100), QtCore.Qt.AlignCenter, vstr)
+                #textRect = p.boundingRect(QtCore.QRectF(0, 0, 100, 100), QtCore.Qt.AlignmentFlag.AlignCenter, vstr)
                 textRect = rects[j]
                 height = textRect.height()
                 width = textRect.width()
@@ -1112,26 +1118,19 @@ class AxisItem(GraphicsWidget):
                 offset = max(0,self.style['tickLength']) + textOffset
 
                 if self.orientation == 'left':
-                    alignFlags = QtCore.Qt.AlignRight|QtCore.Qt.AlignVCenter
+                    alignFlags = QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignVCenter
                     rect = QtCore.QRectF(tickStop-offset-width, x-(height/2), width, height)
                 elif self.orientation == 'right':
-                    alignFlags = QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter
+                    alignFlags = QtCore.Qt.AlignmentFlag.AlignLeft|QtCore.Qt.AlignmentFlag.AlignVCenter
                     rect = QtCore.QRectF(tickStop+offset, x-(height/2), width, height)
                 elif self.orientation == 'top':
-                    alignFlags = QtCore.Qt.AlignHCenter|QtCore.Qt.AlignBottom
+                    alignFlags = QtCore.Qt.AlignmentFlag.AlignHCenter|QtCore.Qt.AlignmentFlag.AlignBottom
                     rect = QtCore.QRectF(x-width/2., tickStop-offset-height, width, height)
                 elif self.orientation == 'bottom':
-                    alignFlags = QtCore.Qt.AlignHCenter|QtCore.Qt.AlignTop
+                    alignFlags = QtCore.Qt.AlignmentFlag.AlignHCenter|QtCore.Qt.AlignmentFlag.AlignTop
                     rect = QtCore.QRectF(x-width/2., tickStop+offset, width, height)
 
-                if QT_LIB == 'PyQt6':
-                    # PyQt6 doesn't allow or-ing of different enum types
-                    # so we need to take its value property
-                    textFlags = alignFlags.value | QtCore.Qt.TextDontClip.value
-                else:
-                    # for PyQt5, the following expression is not commutative!
-                    textFlags = alignFlags | QtCore.Qt.TextDontClip
-
+                textFlags = alignFlags | QtCore.Qt.TextFlag.TextDontClip    
                 #p.setPen(self.pen())
                 #p.drawText(rect, textFlags, vstr)
                 textSpecs.append((rect, textFlags, vstr))
@@ -1145,14 +1144,14 @@ class AxisItem(GraphicsWidget):
     def drawPicture(self, p, axisSpec, tickSpecs, textSpecs):
         profiler = debug.Profiler()
 
-        p.setRenderHint(p.Antialiasing, False)
-        p.setRenderHint(p.TextAntialiasing, True)
+        p.setRenderHint(p.RenderHint.Antialiasing, False)
+        p.setRenderHint(p.RenderHint.TextAntialiasing, True)
 
         ## draw long line along axis
         pen, p1, p2 = axisSpec
         p.setPen(pen)
         p.drawLine(p1, p2)
-        p.translate(0.5,0)  ## resolves some damn pixel ambiguity
+        # p.translate(0.5,0)  ## resolves some damn pixel ambiguity
 
         ## draw ticks
         for pen, p1, p2 in tickSpecs:
@@ -1185,20 +1184,31 @@ class AxisItem(GraphicsWidget):
         else:
             self._updateHeight()
 
-    def wheelEvent(self, ev):
+    def wheelEvent(self, event):
         lv = self.linkedView()
         if lv is None:
             return
-        if self.orientation in ['left', 'right']:
-            lv.wheelEvent(ev, axis=1)
+        # Did the event occur inside the linked ViewBox (and not over the axis iteself)?
+        if lv.sceneBoundingRect().contains(event.scenePos()):
+            # pass event to linked ViewBox without marking it as single axis zoom
+            lv.wheelEvent(event)
         else:
-            lv.wheelEvent(ev, axis=0)
-        ev.accept()
+            # pass event to linked viewbox with appropriate single axis zoom parameter
+            if self.orientation in ['left', 'right']:
+                lv.wheelEvent(event, axis=1)
+            else:
+                lv.wheelEvent(event, axis=0)
+        event.accept()
 
     def mouseDragEvent(self, event):
         lv = self.linkedView()
         if lv is None:
             return
+        # Did the mouse down event occur inside the linked ViewBox (and not the axis)?
+        if lv.sceneBoundingRect().contains(event.buttonDownScenePos()):
+            # pass event to linked ViewBox without marking it as single axis pan
+            return lv.mouseDragEvent(event)
+        # otherwise pass event to linked viewbox with appropriate single axis parameter
         if self.orientation in ['left', 'right']:
             return lv.mouseDragEvent(event, axis=1)
         else:
